import http from './http';
import type { Material } from '@/types/Material';

/**
 * ดึงรายการ Material ทั้งหมดจาก backend
 */
export async function listMaterials(): Promise<Material[]> {
  const { data } = await http.get('/materials');
  return data;
}

/**
 * ดึงข้อมูล Material รายการเดียวโดยใช้ MaterialID
 */
export async function getMaterial(id: number): Promise<Material> {
  const { data } = await http.get(`/materials/${id}`);
  return data;
}

/**
 * สร้าง Material ใหม่
 */
export async function createMaterial(payload: Partial<Material>): Promise<Material> {
  const { data } = await http.post('/materials', payload);
  return data;
}

/**
 * อัปเดต Material ที่มีอยู่
 */
export async function updateMaterial(id: number, payload: Partial<Material>): Promise<Material> {
  const { data } = await http.patch(`/materials/${id}`, payload);
  return data;
}

/**
 * ลบ Material ตาม MaterialID
 */
export async function deleteMaterial(id: number): Promise<void> {
  await http.delete(`/materials/${id}`);
}
