import http from './http';
import type { StockConfig } from '@/types/StockConfig';
import type {
  CreateStockConfigDto,
  UpdateStockConfigDto,
  BatchUpdateManyStockConfigDto,
} from '@/types/StockConfigDto';

/**
 * ดึงรายการ StockConfig ทั้งหมด (optional: ตาม page)
 */
export async function listStockConfigs(pageId?: number): Promise<StockConfig[]> {
    const { data } = await http.get('/stock-config', {
      params: pageId ? { pageId } : undefined, // ✅ แนบ pageId ไป
    });
    return data;
  }

/**
 * ดึง StockConfig รายการเดียว
 */
export async function getStockConfig(id: number): Promise<StockConfig> {
  const { data } = await http.get(`/stock-config/${id}`);
  return data;
}

/**
 * สร้าง StockConfig ใหม่
 */
export async function createStockConfig(payload: CreateStockConfigDto): Promise<any> {
  const { data } = await http.post('/stock-configs', payload);
  return data;
}

/**
 * อัปเดต StockConfig
 */
export async function updateStockConfig(id: number, payload: UpdateStockConfigDto): Promise<StockConfig> {
  const { data } = await http.patch(`/stock-config/${id}`, payload); // ✅ เปลี่ยนเป็น patch
  return data;
}

/**
 * อัปเดตแบบหลายรายการ (batch)
 */
export async function updateManyStockConfigs(payload: BatchUpdateManyStockConfigDto) {
  return await http.patch('/stock-config/batch', payload); // ✅ เปลี่ยนจาก put → patch
}

/**
 * ลบ StockConfig
 */
export async function deleteStockConfig(id: number): Promise<void> {
  await http.delete(`/stock-config/${id}`);
}
