// 📁 src/stores/refresh/refreshAll.ts

import { useMachineStore } from '@/stores/machine'
import { useMaterialStore } from '@/stores/material'
import { useOrderStore } from '@/stores/order'
import { useOrderPriorityStore } from '@/stores/orderPriority'
import { useQueueStore } from '@/stores/queue'
import { useStockConfigStore } from '@/stores/stockConfig'
import { useProductStore } from '@/stores/product'
import { useProductionTargetStore } from '@/stores/productionTarget'
import { useLoadingStore } from '@/stores/loading' // ✅ เพิ่ม loading store

export async function refreshAllData() {
  const loadingStore = useLoadingStore() // ✅ เรียก loading store

  try {
    loadingStore.doLoad() // ✅ เริ่มโหลด

    // รอ 3 วินาที
    await new Promise((resolve) => setTimeout(resolve, 3000))

    // เรียกทุก store
    const machineStore = useMachineStore()
    const materialStore = useMaterialStore()
    const orderStore = useOrderStore()
    const orderPriorityStore = useOrderPriorityStore()
    const queueStore = useQueueStore()
    const stockConfigStore = useStockConfigStore()
    const productStore = useProductStore()
    const productionTargetStore = useProductionTargetStore()

    await Promise.all([
      machineStore.fetchMachines(),
      materialStore.fetchMaterials(),
      orderStore.fetchOrders(),
      orderPriorityStore.fetchAll(),
      queueStore.fetchQueues(),
      stockConfigStore.fetchStockConfigs(),
      productStore.fetchProducts(),
      productionTargetStore.fetchProductionTargets()
    ])

    console.log('✅ Refreshed all data.')
  } catch (err) {
    console.error('❌ Error refreshing data:', err)
  } finally {
    loadingStore.finish() // ✅ จบโหลด
  }
}
